ChunkDecoder class final

Decodes LZF-encoded data into its original (uncompressed) form.

This decoder processes both compressed and uncompressed LZF chunks.

Constructors

ChunkDecoder()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Uint8List data, {int offset = 0}) Uint8List
Decodes an entire LZF-encoded data buffer starting at offset.
decodeChunk(Uint8List data, Uint8List output) Uint8List
Decodes a single LZF chunk given in data into output.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited