A utility class for decoding LZF-encoded data.
This class provides a simple static API to decode LZF data into its original, uncompressed form.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Uint8List data) → Uint8List -
Decodes the provided LZF-encoded
data. -
decodeWithDecoder(
ChunkDecoder decoder, Uint8List data) → Uint8List -
Decodes the provided LZF-encoded
datausing a customdecoder.