A utility class for encoding data into LZF format.
This class provides static methods for encoding raw data into one or more LZF chunks and coalescing them into a single contiguous Uint8List.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
encode(
Uint8List data) → Uint8List -
Encodes the entire
databuffer. -
encodeWithEncoder(
ChunkEncoder encoder, Uint8List data) → Uint8List -
Encodes the
databuffer using the providedencoder.